#!/usr/bin/env python
# coding: utf-8

# ## Active Fires Scraper
# 

# #### Run this cell to connect to your GIS and get started:

# In[1]:


# Importing libraries
import pandas as pd
from arcgis.gis import GIS
import csv
gis = GIS("home")


# #### Now you are ready to start!

# In[2]:


# Scraping the Active Fires csv from the downloads folder of CWFIS
url = "https://cwfis.cfs.nrcan.gc.ca/downloads/activefires/activefires.csv"
c = pd.read_csv(url) # Parse csv through a dataframe
display(c) # Display the pandas table


# In[3]:


# print the number of records in this csv
c.shape


# In[4]:


SERVICE_NAME = "cwfis_active_fires_test"
SERVICE_TITLE = "cwfis_active_fires_test"
CSV_FILE="/arcgis/home/{0}.csv".format(SERVICE_NAME)

c.to_csv(CSV_FILE, index=False)
csv_item = None
csv_items = gis.content.search(query="{0}.csv".format(SERVICE_NAME))
if len(csv_items) > 0:
    print("Using existing item!")
    csv_item = csv_items[0]
    csv_item.update(data=CSV_FILE)
else:
    print("Creating new item!")
    item_properties = {
        "title": SERVICE_TITLE,
        "name": SERVICE_NAME,
        "type": "CSV",
        "locationType":"none"
    }
    csv_item = gis.content.add(
        item_properties=item_properties,
        data=CSV_FILE
    )
source_info = gis.content.analyze(item=csv_item)
source_info["name"] = SERVICE_NAME
source_info["title"] = SERVICE_TITLE
csv_layer_item = csv_item.publish(
    publish_parameters=source_info["publishParameters"],
    file_type="csv",
    overwrite=True
)
display(csv_layer_item)


# In[ ]:




